//
//  Test_qtmulQV3.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_qtmulQV3_h
#define BulletTest_Test_qtmulQV3_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_qtmulQV3(void);

#ifdef __cplusplus
}
#endif

#endif
